@@ -28,23 +28,39 @@ class UserManager(BaseUserManager):
     use_in_migrations = True
 
     def _create_user(self, email, password,
-                     is_staff, is_superuser, **extra_fields):
+                     is_staff, is_superuser, is_guest=False, **extra_fields):
         """
         Creates and saves a User with the given username, email and password.
         """
         now = timezone.now()
         email = self.normalize_email(email)
-        user = self.model(email=email,
-                          is_staff=is_staff, is_active=True,
-                          is_superuser=is_superuser,
-                          date_joined=now,
-                          is_email_verified=False, **extra_fields)
+        try:
+            user = self.model.objects.get(email=email, is_guest=True)
+
+            self.model.objects.filter(id=user.id).update(
+              is_staff=is_staff,
+              is_active=True,
+              is_superuser=is_superuser,
+              is_guest=is_guest,
+              date_joined=now,
+              is_email_verified=False, **extra_fields)
+
+        except self.model.DoesNotExist:
+            user = self.model(email=email,
+                              is_staff=is_staff,
+                              is_active=True,
+                              is_guest=is_guest,
+                              is_superuser=is_superuser,
+                              date_joined=now,
+                              is_email_verified=False, **extra_fields)
+        if password is None:
+            password = self.make_random_password()
         user.set_password(password)
         user.save(using=self._db)
         return user
 
-    def create_user(self, email, password=None, **extra_fields):
-        return self._create_user(email, password, False, False,
+    def create_user(self, email, password=None, is_guest=False, **extra_fields):
+        return self._create_user(email, password, False, False, is_guest=is_guest,
                                  **extra_fields)
 
     def create_superuser(self, email, password, **extra_fields):
@@ -60,7 +76,8 @@ class User(AbstractBaseUser, PermissionsMixin):
     phone_number = models.CharField(
         null=True,
         max_length=20,
-        validators=[validate_gb_phone_number]
+        validators=[validate_gb_phone_number],
+        blank=True
     )
     profile_pic = models.ImageField(blank=True, null=True)
     is_staff = models.BooleanField(_('staff status'), default=False,
@@ -69,6 +86,10 @@ class User(AbstractBaseUser, PermissionsMixin):
     is_active = models.BooleanField(_('active'), default=True,
                                     help_text=_('Designates whether this user should be treated as '
                                                 'active. Unselect this instead of deleting accounts.'))
+    is_guest = models.BooleanField(_('guest'), default=False,
+                                    help_text=_('Designates whether this user should be treated as '
+                                                'Guest. Guest accounts are created for users who don\'t '
+                                                'want to or can\'t create an account so it is created for them'))
     date_joined = models.DateTimeField(_('date joined'), default=timezone.now)
 
     is_email_verified = models.BooleanField(_('email verified'), default=False,
@@ -112,6 +133,10 @@ class User(AbstractBaseUser, PermissionsMixin):
 
     def send_verification_email(self, request=None):
 
+        #safeguard if guest
+        if self.is_guest:
+            return
+
         preview = ''
         passkey = ''
 
@@ -150,6 +175,11 @@ class User(AbstractBaseUser, PermissionsMixin):
         )
 
     def send_password_reset_email(self):
+
+        # safeguard if guest
+        if self.is_guest:
+            return
+
         uidb64 = urlsafe_base64_encode(force_bytes(self.pk))
         
         token = default_token_generator.make_token(self)
