@@ -1,4 +1,5 @@
 from datetime import timedelta
+from rest_framework.validators import UniqueValidator
 
 from django.conf import settings
 from django.contrib.auth import authenticate, get_user_model, update_session_auth_hash
@@ -21,9 +22,10 @@ from rest_framework.exceptions import ValidationError
 from .auth import generate_verify_email_token
 from .models import ImageAsset, Article, ArticleCollection, ArticleOrder, ArticleCollectionOrder, RichTextAsset, TextAsset
 from .models import User, FeatureOption, FeatureUrl
+import logging
 
 user_model = get_user_model()
-
+logger = logging.getLogger(__name__)
 
 class FeatureUrlSerializer(serializers.ModelSerializer):
     class Meta:
@@ -76,10 +78,10 @@ class UserSerializer(serializers.ModelSerializer):
     class Meta:
         model = user_model
         fields = ('id', 'email', 'first_name', 'last_name', 'profile_pic',
-                  'phone_number', 'is_authenticated', 'is_admin', 'is_staff',
+                  'phone_number', 'is_authenticated', 'is_admin', 'is_staff', 'is_guest',
                   'is_email_verified')
         read_only_fields = ['is_authenticated',
-                            'is_admin', 'is_staff', 'is_email_verified']
+                            'is_admin', 'is_staff', 'is_guest', 'is_email_verified']
 
 
 class ImageAssetSerializer(serializers.ModelSerializer):
@@ -205,6 +207,7 @@ class SignUpSerializer(serializers.ModelSerializer):
 
     password_confirm = serializers.CharField(write_only=True)
     first_name = serializers.CharField(required=True)
+    email = serializers.EmailField(validators=[UniqueValidator(user_model.objects.filter(is_guest=False), 'user with this email address already exists.')])
 
     class Meta:
         model = user_model
